==> nextcloud-27.1.3.tgz: nextcloud/apps/comments/l10n/en_GB.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Comments",
    "You commented" : "You commented",
    "{author} commented" : "{author} commented",
    "You commented on %1$s" : "You commented on %1$s",
    "You commented on {file}" : "You commented on {file}",
    "%1$s commented on %2$s" : "%1$s commented on %2$s",
    "{author} commented on {file}" : "{author} commented on {file}",
    "<strong>Comments</strong> for files" : "<strong>Comments</strong> for files",
    "You were mentioned on \"{file}\", in a comment by a user that has since been deleted" : "You were mentioned on \"{file}\", in a comment by a user that has since been deleted",
    "{user} mentioned you in a comment on \"{file}\"" : "{user} mentioned you in a comment on \"{file}\"",
    "Files app plugin to add comments to files" : "Files app plugin to add comments to files",
    "Edit comment" : "Edit comment",
    "Delete comment" : "Delete comment",
    "Cancel edit" : "Cancel edit",
    "Post comment" : "Post comment",
    "\"@\" for mentions, \":\" for emoji, \"/\" for smart picker" : "\"@\" for mentions, \":\" for emoji, \"/\" for smart picker",
    "No comments yet, start the conversation!" : "No comments yet, start the conversation!",
    "No more messages" : "No more messages",
    "Retry" : "Retry",
    "Failed to mark comments as read" : "Failed to mark comments as read",
    "Unable to load the comments list" : "Unable to load the comments list",
    "_1 new comment_::_{unread} new comments_" : ["1 new comment","{unread} new comments"],
    "Comment" : "Comment",
    "An error occurred while trying to edit the comment" : "An error occurred while trying to edit the comment",
    "Comment deleted" : "Comment deleted",
    "An error occurred while trying to delete the comment" : "An error occurred while trying to delete the comment",
    "An error occurred while trying to create the comment" : "An error occurred while trying to create the comment",
    "%1$s commented" : "%1$s commented",
    "_%n unread comment_::_%n unread comments_" : ["%n unread comment","%n unread comments"]
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-27.1.7p0.tgz: nextcloud/apps/comments/l10n/en_GB.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Comments",
    "You commented" : "You commented",
    "{author} commented" : "{author} commented",
    "You commented on %1$s" : "You commented on %1$s",
    "You commented on {file}" : "You commented on {file}",
    "%1$s commented on %2$s" : "%1$s commented on %2$s",
    "{author} commented on {file}" : "{author} commented on {file}",
    "<strong>Comments</strong> for files" : "<strong>Comments</strong> for files",
    "You were mentioned on \"{file}\", in a comment by an account that has since been deleted" : "You were mentioned on \"{file}\", in a comment by an account that has since been deleted",
    "{user} mentioned you in a comment on \"{file}\"" : "{user} mentioned you in a comment on \"{file}\"",
    "Files app plugin to add comments to files" : "Files app plugin to add comments to files",
    "Edit comment" : "Edit comment",
    "Delete comment" : "Delete comment",
    "Cancel edit" : "Cancel edit",
    "New comment" : "New comment",
    "Write a comment …" : "Write a comment …",
    "Post comment" : "Post comment",
    "@ for mentions, : for emoji, / for smart picker" : "@ for mentions, : for emoji, / for smart picker",
    "Could not reload comments" : "Could not reload comments",
    "No comments yet, start the conversation!" : "No comments yet, start the conversation!",
    "No more messages" : "No more messages",
    "Retry" : "Retry",
    "Failed to mark comments as read" : "Failed to mark comments as read",
    "Unable to load the comments list" : "Unable to load the comments list",
    "_1 new comment_::_{unread} new comments_" : ["1 new comment","{unread} new comments"],
    "Comment" : "Comment",
    "An error occurred while trying to edit the comment" : "An error occurred while trying to edit the comment",
    "Comment deleted" : "Comment deleted",
    "An error occurred while trying to delete the comment" : "An error occurred while trying to delete the comment",
    "An error occurred while trying to create the comment" : "An error occurred while trying to create the comment",
    "You were mentioned on \"{file}\", in a comment by a user that has since been deleted" : "You were mentioned on \"{file}\", in a comment by a user that has since been deleted",
    "_%n unread comment_::_%n unread comments_" : ["%n unread comment","%n unread comments"]
},
"nplurals=2; plural=(n != 1);");
